/// \page modbusbreakdown Modbus Function by Sealevel Model Number
///
/// \section mbbd_01 SeaI/O Modules
///
/// The following list enumerates all the relavent Modbus functions for each model of SeaI/O module.
///
/// \li \subpage mbbd_seaio_410 "Model 410"
/// \li \subpage mbbd_seaio_420 "Model 420"
/// \li \subpage mbbd_seaio_430 "Model 430"
/// \li \subpage mbbd_seaio_440 "Model 440"
/// \li \subpage mbbd_seaio_450 "Model 450"
/// \li \subpage mbbd_seaio_462 "Model 462"
/// \li \subpage mbbd_seaio_463 "Model 463"
/// \li \subpage mbbd_seaio_470 "Model 470"
/// \li \subpage mbbd_seaio_520 "Model 520"
/// \li \subpage mbbd_seaio_530 "Model 530"
/// \li \subpage mbbd_seaio_540 "Model 540"
/// \li \subpage mbbd_seaio_570 "Model 570"
/// \li \subpage mbbd_seaio_580 "Model 580"
///
/// \section mbbd_02 SeaDAC Modules
///
/// \li \subpage mbbd_seadac_8221 "Model 8221"
/// \li \subpage mbbd_seadac_8222 "Model 8222"
/// \li \subpage mbbd_seadac_8223 "Model 8223"
/// \li \subpage mbbd_seadac_8224 "Model 8224"
/// \li \subpage mbbd_seadac_8225 "Model 8225"
/// \li \subpage mbbd_seadac_8227 "Model 8227"
/// \li \subpage mbbd_seadac_8232 "Model 8232"
///
/// \section mbbd_03 SeaDAC Lite Modules
///
/// The SeaDAC Lite modules are USB modules and do not provide a serial interface.  Therefore, they do
/// not support any Modbus functionality.
///
/// \section mbbd_04 eI/O Modules
///
/// \li \subpage mbbd_eio_110 "Model 110"
/// \li \subpage mbbd_eio_120 "Model 120"
/// \li \subpage mbbd_eio_130 "Model 130"
/// \li \subpage mbbd_eio_140 "Model 140"
/// \li \subpage mbbd_eio_150 "Model 150"
/// \li \subpage mbbd_eio_160 "Model 160"
/// \li \subpage mbbd_eio_170 "Model 170"
///
/// \section mbbd_05 SeaRAQ Modules
///
/// \li \subpage mbbd_searaq_6510 "Model 6510"
/// \li \subpage mbbd_searaq_6511 "Model 6511"
/// \li \subpage mbbd_searaq_6512 "Model 6512"
/// \li \subpage mbbd_searaq_6513 "Model 6513"
/// \li \subpage mbbd_searaq_6520 "Model 6520"
/// \li \subpage mbbd_searaq_6525 "Model 6525"
/// \li \subpage mbbd_searaq_8510 "Model 8510"
/// \li \subpage mbbd_searaq_8511 "Model 8511"
/// \li \subpage mbbd_searaq_8512 "Model 8512"
/// \li \subpage mbbd_searaq_8513 "Model 8513"
/// \li \subpage mbbd_searaq_8520 "Model 8520"
/// \li \subpage mbbd_searaq_8521 "Model 8521"
/// \li \subpage mbbd_searaq_8522 "Model 8522"
/// \li \subpage mbbd_searaq_8523 "Model 8523"
///
/// \section mbbd_06 SeaConnect Modules
///
/// \li \subpage mbbd_seaconnect_370 "Model 370"

/// \page mbbd_seaio_410 SeaIO 410
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the state of reed relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes to a single reed relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes multiple reed relay outputs.</td>
/// </tr>
///
/// </table>


/// \page mbbd_seadac_8221 SeaDAC 8221
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the state of reed relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes to a single reed relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes multiple reed relay outputs.</td>
/// </tr>
///
/// </table>


/// \page mbbd_seaio_420 SeaIO 420
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the state of form C outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes to a single form C output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes multiple form C outputs.</td>
/// </tr>
///
/// </table>


/// \page mbbd_seadac_8222 SeaDAC 8222
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the state of form C outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes to a single form C output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes multiple form C outputs.</td>
/// </tr>
///
/// </table>


/// \page mbbd_seaio_430 SeaIO 430
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// </table>



/// \page mbbd_seadac_8223 SeaDAC 8223
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// </table>



/// \page mbbd_seaio_440 SeaIO 440
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Reads the state of reed relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Writes to a single reed relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Writes multiple reed relay outputs.</td>
/// </tr>
///
/// </table>


/// \page mbbd_seadac_8224 SeaDAC 8224
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Reads the state of reed relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Writes to a single reed relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Writes multiple reed relay outputs.</td>
/// </tr>
///
/// </table>



/// \page mbbd_seaio_450 SeaIO 450
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the state of form C outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes to a single form C output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes multiple form C outputs.</td>
/// </tr>
///
/// </table>


/// \page mbbd_seadac_8225 SeaDAC 8225
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memItemRight">Reads the state of form C outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memItemRight">Writes to a single form C output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes multiple form C outputs.</td>
/// </tr>
/// </table>



/// \page mbbd_seaio_462 SeaIO 462
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 95</td>
///     <td class="memMbbdCellNotes">Reads the state of TTL outputs, skipping over inputs. Uses absolute addressing. Usable with 1 or 8 outputs only. Must start at a multiple of 8 when reading 8 outputs. (ie. 16-23)</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 95</td>
///     <td class="memMbbdCellNotes">Reads the TTL inputs, skipping over outputs. Uses absolute addressing. Usable with 1 or 8 inputs only. Must start at a multiple of 8 when reading 8 inputs. (ie. 16-23)</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 95</td>
///     <td class="memMbbdCellNotes">Writes to a single TTL output. Uses absolute addressing.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 95</td>
///     <td class="memMbbdCellNotes">Writes multiple TTL outputs, skipping over inputs. Uses absolute addressing. Usable with 1 or 8 outputs only. Must start at a multiple of 8 when writing 8 outputs. (ie. 16-23)</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_41</td>
///		<td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">Reads the entire 96-bit I/O space.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_42</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">Writes the entire 96-bit I/O space, masking out inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_03</td>
///     <td class="memMbbdCellParams">0 - 8</td>
///     <td class="memMbbdCellNotes">Reads the state of the \ref seaIO46xRegisters.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_06</td>
///     <td class="memMbbdCellParams">1 - 8</td>
///     <td class="memMbbdCellNotes">Configures the module based on the \ref seaIO46xRegisters</td>
/// </tr>
/// </table>

/// \page mbbd_seaio_463 SeaIO 463
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 95</td>
///     <td class="memMbbdCellNotes">Reads the state of TTL outputs, skipping over inputs. Uses absolute addressing. Usable with 1 or 8 outputs only. Must start at a multiple of 8 when reading 8 outputs. (ie. 16-23)</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 95</td>
///     <td class="memMbbdCellNotes">Reads the TTL inputs, skipping over outputs. Uses absolute addressing. Usable with 1 or 8 inputs only. Must start at a multiple of 8 when reading 8 inputs. (ie. 16-23)</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 95</td>
///     <td class="memMbbdCellNotes">Writes to a single TTL output. Uses absolute addressing.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 95</td>
///     <td class="memMbbdCellNotes">Writes multiple TTL outputs, skipping over inputs. Uses absolute addressing. Usable with 1 or 8 outputs only. Must start at a multiple of 8 when writing 8 outputs. (ie. 16-23)</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_41</td>
///		<td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">Reads the entire 96-bit I/O space.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_42</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">Writes the entire 96-bit I/O space, masking out inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_03</td>
///     <td class="memMbbdCellParams">0 - 8</td>
///     <td class="memMbbdCellNotes">Reads the state of the \ref seaIO46xRegisters.</td>
/// </tr>
///
/// </table>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td class="memMbbdCellLink">\ref mb_06</td>
///     <td class="memMbbdCellParams">1 - 8</td>
///     <td class="memMbbdCellNotes">Configures the module based on the \ref seaIO46xRegisters</td>
///
/// </table>

/// \page mbbd_seaconnect_370 SeaConnect 370
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Reads the state of open collector outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Writes to a single open collector output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Writes multiple open collector outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_04</td>
///     <td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Reads the analog single-ended/differential inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_64</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Sets the A/D and D/A configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_65</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Gets the A/D and D/A configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_66</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">Gets the hardware jumper configuration.</td>
/// </tr>
/// </table>
///

/// \page mbbd_seaio_470 SeaIO 470
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the state of open collector outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes to a single open collector output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes multiple open collector outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_04</td>
///     <td class="memMbbdCellParams">0 - 15/7</td>
///     <td class="memMbbdCellNotes">Reads the analog single-ended/differential inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_06</td>
///     <td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Writes to a single analog output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_10</td>
///     <td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Writes multiple analog outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_64</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Sets the A/D and D/A configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_65</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Gets the A/D and D/A configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_66</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">Gets the hardware jumper configuration.</td>
/// </tr>
/// </table>
///

/// \page mbbd_seadac_8227 SeaDAC 8227
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the state of open collector outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes to a single open collector output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes multiple open collector outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_04</td>
///     <td class="memMbbdCellParams">0 - 15/7</td>
///     <td class="memMbbdCellNotes">Reads the analog single-ended/differential inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_06</td>
///     <td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Writes to a single analog output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_10</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes multiple analog outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_64</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Sets the A/D and D/A configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_65</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Gets the A/D and D/A configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_66</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">Gets the hardware jumper configuration.</td>
/// </tr>
///
/// </table>
///


/// \page mbbd_seaio_520 SeaIO 520
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the state of form C outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes to a single form C output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes multiple form C outputs.</td>
/// </tr>
///
/// </table>


/// \page mbbd_seaio_530 SeaIO 530
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the state of open collector outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes to a single open collector output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes multiple open collector outputs.</td>
/// </tr>
///
/// </table>


/// \page mbbd_seaio_540 SeaIO 540
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Reads the state of open collector outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Writes to a single open collector output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Writes multiple open collector outputs.</td>
/// </tr>
///
/// </table>


/// \page mbbd_seaio_570 SeaIO 570
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the state of form C outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes to a single form C output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes multiple form C outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_04</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the analog floating/ground referenced inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_64</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Sets the A/D configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_65</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Gets the A/D configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_66</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">Gets the hardware jumper configuration.</td>
/// </tr>
///
/// </table>
///


/// \page mbbd_seaio_580 SeaIO 580
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 31</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// </table>


/// \page mbbd_seadac_8232 SeaDAC 8232
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the state of form C outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes to a single form C output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes multiple form C outputs.</td>
/// </tr>
///
/// </table>

/// \page mbbd_eio_110 eIO 110
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Reads the state of reed relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes to a single reed relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes multiple reed relay outputs.</td>
/// </tr>
///
/// </table>

/// \page mbbd_eio_120 eIO 120
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Reads the state of form C outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes to a single form C output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes multiple form C outputs.</td>
/// </tr>
///
/// </table>

/// \page mbbd_eio_130 eIO 130
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// </table>

/// \page mbbd_eio_140 eIO 140
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Reads the state of reed relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes to a single reed relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes multiple reed relay outputs.</td>
/// </tr>
///
/// </table>

/// \page mbbd_eio_150 eIO 150
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Reads the state of form C outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes to a single form C output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes multiple form C outputs.</td>
/// </tr>
///
/// </table>

/// \page mbbd_eio_160 eIO 160
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_41</td>
///		<td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">Reads the entire 32-bit I/O space.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_42</td>
///		<td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">Writes the entire 32-bit I/O space, masking out inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_03</td>
///     <td class="memMbbdCellParams">0 - 8</td>
///     <td class="memMbbdCellNotes">Reads the state of the \ref seaIO46xRegisters.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_06</td>
///     <td class="memMbbdCellParams">1 - 8</td>
///     <td class="memMbbdCellNotes">Configures the module based on the \ref seaIO46xRegisters.  Note that registers 1 and 2 of the 160 may be used to read / write the TTL IO.</td>
/// </tr>
///
/// </table>

/// \page mbbd_eio_170 eIO 170
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Reads the opto-isolated inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Reads the state of solid-state relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Writes to a single solid-state relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 1</td>
///     <td class="memMbbdCellNotes">Writes multiple solid-state relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_04</td>
///     <td class="memMbbdCellParams">0 - 7/3</td>
///     <td class="memMbbdCellNotes">Reads the analog single-ended/differential inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_64</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Sets the A/D configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_65</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Gets the A/D configuration.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_6510 SeaRAQ 6510
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_04</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the analog inputs.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_6511 SeaRAQ 6511
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_04</td>
///     <td class="memMbbdCellParams">0 - 5</td>
///     <td class="memMbbdCellNotes">Reads the analog inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_64</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Sets the A/D configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_65</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Gets the A/D configuration.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_6512 SeaRAQ 6512
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_04</td>
///     <td class="memMbbdCellParams">0 - 5</td>
///     <td class="memMbbdCellNotes">Reads the analog inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_64</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Sets the A/D configuration.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_65</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Gets the A/D configuration.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_6513 SeaRAQ 6513
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_04</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the analog inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_64</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Sets the A/D configuration.<br>
///							  * Range = ch[n] + (ch[n + 8] &lt;&lt; 2)<br></td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_65</td>
///     <td class="memMbbdCellParams">n/a</td>
///     <td class="memMbbdCellNotes">* Gets the A/D configuration.<br>
///							  * Range = ch[n] + (ch[n + 8] &lt;&lt; 2)<br></td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_6520 SeaRAQ 6520
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_06</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes to a single analog output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_10</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes multiple analog outputs.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_6525 SeaRAQ 6525
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_06</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes to a single analog output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_10</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes multiple analog outputs.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_8510 SeaRAQ 8510
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the digital inputs.</td>
/// </tr>
///

/// \page mbbd_searaq_8511 SeaRAQ 8511
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the digital inputs.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_8512 SeaRAQ 8512
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the digital inputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Reads the state of the relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes to a single relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes multiple relay outputs.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_8513 SeaRAQ 8513
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_02</td>
///		<td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the digital inputs.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_8520 SeaRAQ 8520
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the state of the relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes to a single relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes multiple relay outputs.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_8521 SeaRAQ 8521
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Reads the state of the relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes to a single relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 7</td>
///     <td class="memMbbdCellNotes">Writes multiple relay outputs.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_8522 SeaRAQ 8522
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Reads the state of the relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes to a single relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 3</td>
///     <td class="memMbbdCellNotes">Writes multiple relay outputs.</td>
/// </tr>
///
/// </table>
///

/// \page mbbd_searaq_8523 SeaRAQ 8523
/// <br><br>
/// <table border="0" width="75%" cellspacing="0" cellpadding="10">
///
/// <tr><td><b>Modbus Function</b></td><td><b>Valid&nbsp;Range</b></td><td><b><i>Description</i></b></td></tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_01</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Reads the state of the relay outputs.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_05</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes to a single relay output.</td>
/// </tr>
///
/// <tr><td class="memMbbdCellLink">\ref mb_0f</td>
///     <td class="memMbbdCellParams">0 - 15</td>
///     <td class="memMbbdCellNotes">Writes multiple relay outputs.</td>
/// </tr>
///
/// </table>
///