/// \page	Speaking_Modbus	Communicating Via Modbus
///	The Sealevel SeaI/O series of digital I/O communicates serially using the %Modbus protocol (http://www.modbus.org).
///	
///	Enumerated below are the standard %Modbus functions supported by the SeaI/O series of digital I/O.  Following those are the
///	Sealevel SeaI/O specific custom functions used for configuring and manipulating specific SeaI/O modules.  
/// 
///	\section	modbus_functions	Standard Modbus Functions
///
///
/// \subsection	mb_01	(0x01)  Read Coils
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Read Coils' Modbus PDU (0x01) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Start Address||Quantity|}|{0x01|? (High)|? (Low)|? (High)|? (Low)}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Byte Count|Input Status}|{0x01|N|N Bytes}"	]
///		}
///	}
/// \enddot	
///
///
///
///
/// \subsection	mb_02	(0x02)  Read Discrete Inputs
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Read Discrete Inputs' Modbus PDU (0x02) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Start Address||Quantity|}|{0x02|? (High)|? (Low)|? (High)|? (Low)}" ]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Byte Count|Input Status}|{0x02|N|N Bytes}"	]
///		}
///	}
/// \enddot	
///
///
///
/// \subsection	mb_03	(0x03)  Read Holding Registers
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Read Holding Registers' Modbus PDU (0x03) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Start Address||Quantity|}|{0x03|? (High)|? (Low)|? (High)|? (Low)}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Byte Count|Input Status}|{0x03|N|2*N Bytes}"	]
///		}
///	}
/// \enddot	
///
///
///
///
/// \subsection	mb_04	(0x04)  Read Input Registers
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Read Input Registers' Modbus PDU (0x04) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Start Address||Quantity|}|{0x04|? (High)|? (Low)|? (High)|? (Low)}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Byte Count|Input Status}|{0x04|N|2*N Bytes}"	]
///		}
///	}
/// \enddot	
///
///
///
///
/// \subsection	mb_05	(0x05)  Write Single Coil
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Write Single Coil' Modbus PDU (0x05) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Output Address||Output Value|}|{0x05|? (High)|? (Low)|0x00 or 0xFF (High)|0x00 (Low)}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Output Address||Output Value|}|{0x05|? (High)|? (Low)|0x00 or 0xFF (High)|0x00 (Low)}"	]
///		}
///	}
/// \enddot	
///
///
///
///
/// \subsection	mb_06	(0x06)  Write Single Register
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=10, style=solid, color="#999999" ]
///
///		graph [	label="'Write Single Register' Modbus PDU (0x06) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Register Address||Register Value|}|{0x06|? (High)|? (Low)|? (High)|? (Low)}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Register Address||Register Value|}|{0x06|? (High)|? (Low)|? (High)|? (Low)}"	]
///		}
///	}
/// \enddot	
///
///
///
///
/// \subsection	mb_0f	(0x0F)  Write Multiple Coils
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Write Multiple Coils' Modbus PDU (0x0F) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Starting Address||Quantity||Byte Count|Outputs Values}|{0x0F|? (High)|? (Low)|? (High)|? (Low)|N|N Bytes}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Starting Address||Quantity|}|{0x0F|? (High)|? (Low)|? (High)|? (Low)}"	]
///		}
///	}
/// \enddot	
///
///
///
///
/// \subsection	mb_10	(0x10)  Write Multiple Registers
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=10, style=solid, color="#999999" ]
///
///		graph [	label="'Write Multiple Registers' Modbus PDU (0x10) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Starting Address||Quantity||Byte Count|Registers Values}|{0x10|? (High)|? (Low)|? (High)|? (Low)|N|2*N Bytes}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Starting Address||Quantity|}|{0x10|? (High)|? (Low)|? (High)|? (Low)}"	]
///		}
///	}
/// \enddot	
///
///
///
/// \section sealevel_functions Sealevel SeaI/O Specific Modbus Functions
///
///
///
///
///
/// \subsection	mb_41	(0x41)  Read Programmable IO
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Read Programmable IO' Modbus PDU (0x41) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function}|{0x41}" ]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Model\n\ |Config (Banks 6-11)|Config (Banks 0-5)|Bank 0|Bank 1|Bank 2|Bank 3|Bank 4|Bank 5|Bank 6|Bank 7|Bank 8|Bank 9|Bank 10|Bank 11}|{0x41|Model\nLow Byte|?|?|?|?|?|?|?|?|?|?|?|?|?|?}"	]
///		}
///	}
/// \enddot	
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=plaintext, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="Parameter 'config' Layout of IO Direction"]
///
///		c [ label=<
///		<table border="0" cellspacing="0" cellpadding="5">
///		<tr>
///			<td border="0"></td>
///			<td border="1">Bit 7</td>
///			<td border="1">Bit 6</td>
///			<td border="1">Bit 5</td>
///			<td border="1">Bit 4</td>
///			<td border="1">Bit 3</td>
///			<td border="1">Bit 2</td>
///			<td border="1">Bit 1</td>
///			<td border="1">Bit 0</td>
///		</tr>
///		<tr>
///			<td border="1">Config (Banks 6-11) Byte</td>
///			<td border="1">x</td>
///			<td border="1">x</td>
///			<td border="1">Bank 11</td>
///			<td border="1">Bank 10</td>
///			<td border="1">Bank 9</td>
///			<td border="1">Bank 8</td>
///			<td border="1">Bank 7</td>
///			<td border="1">Bank 6</td>
///		</tr>
///		<tr>
///			<td border="1">Config (Banks 0-5) Byte</td>
///			<td border="1">x</td>
///			<td border="1">x</td>
///			<td border="1">Bank 5</td>
///			<td border="1">Bank 4</td>
///			<td border="1">Bank 3</td>
///			<td border="1">Bank 2</td>
///			<td border="1">Bank 1</td>
///			<td border="1">Bank 0</td>
///		</tr>
///		</table>
///		>]
///
///		l [ label=<
///		<table border="0" cellspacing="0" cellpadding="5">
///		<tr>
///			<td border="0">Legend</td>
///		</tr>
///		<tr>
///			<td border="1">'0' = Bank of 8 Outputs</td>
///		</tr>
///		<tr>
///         <td border="1">'1' = Bank of 8 Inputs</td>
///		</tr>
///		</table>
///		>]
///	}
/// \enddot	
///
///
///
///
/// \subsection	mb_42	(0x42)  Write Programmable IO
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Write Programmable IO' Modbus PDU (0x42) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Bank 0|Bank 1|Bank 2|Bank 3|Bank 4|Bank 5|Bank 6|Bank 7|Bank 8|Bank 9|Bank 10|Bank 11}|{0x42|?|?|?|?|?|?|?|?|?|?|?|?}" ]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Bank 0|Bank 1|Bank 2|Bank 3|Bank 4|Bank 5|Bank 6|Bank 7|Bank 8|Bank 9|Bank 10|Bank 11}|{0x42|?|?|?|?|?|?|?|?|?|?|?|?}" ]
///		}
///	}
/// \enddot	
///
///
///
/// \subsection	mb_45	(0x45)  Get Module Configuration
///
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Get Module Configuration' Modbus PDU (0x45) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function}|{0x45}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Model|Comm Type|Baudrate|Parity|Security Key}|{0x45|?|?|?|?|?}"	]
///		}
///	}
/// \enddot	
///
///
///
///
/// \subsection	mb_46	(0x46)  Set Software Slave ID
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Set Software Slave ID' Modbus PDU (0x46) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Desired Address|Reserved|Security Key\n\ }|{0x46|?|0x00|From Previous\n'Get Config' Request}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Desired Address|Reserved|Security Key\n\ }|{0x46|?|0x00|Previous\nSecurity Key}"	]
///		}
///	}
/// \enddot	
///
///
///
///
/// \subsection	mb_47	(0x47)  Set Communications
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Set Communications' Modbus PDU (0x47) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Baudrate|Parity|Security Key\n\ }|{0x47|?|?|From Previous\n'Get Config' Request}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Baudrate|Parity|Security Key\n\ }|{0x47|?|?|Previous\nSecurity Key}"	]
///		}
///	}
/// \enddot	
///
///
///
/// \subsection	mb_64	(0x64)  Set A/D & D/A Configuration
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Set A/D, D/A Configuration' Modbus PDU (0x64) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function|Device Config|Channels 1-4|Channels 5-8|Channels 9-12|Channels 13-16}|{0x64|?|?|?|?|?}" ]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Error Code\nIf Any}|{0x64|?\n\ }"	]
///		}
///	}
/// \enddot	
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=plaintext, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="Parameter 'config' Layout of IO Direction"]
///
///		subgraph cluster_3
///		{
///		label="Device Config Bit Packing"
///		d [ label=<
///		<table border="0" cellspacing="0" cellpadding="5">
///		<tr>
///			<td border="0"></td>
///			<td border="1">Bit 7</td>
///			<td border="1">Bit 6</td>
///			<td border="1">Bit 5</td>
///			<td border="1">Bit 4</td>
///			<td border="1">Bit 3</td>
///			<td border="1">Bit 2</td>
///			<td border="1">Bit 1</td>
///			<td border="1">Bit 0</td>
///		</tr>
///		<tr>
///			<td border="1">Device Config Byte</td>
///			<td border="1" colspan="4">A/D Voltage Reference</td>
///			<td border="1" colspan="4">A/D Channel Mode</td>
///		</tr>
///		</table>
///		>]
///		}
///
///		subgraph cluster_4
///		{
///		label="Channels Config Bit Packing"
///		c [ label=<
///		<table border="0" cellspacing="0" cellpadding="5">
///		<tr>
///			<td border="0"></td>
///			<td border="1">Bit 7</td>
///			<td border="1">Bit 6</td>
///			<td border="1">Bit 5</td>
///			<td border="1">Bit 4</td>
///			<td border="1">Bit 3</td>
///			<td border="1">Bit 2</td>
///			<td border="1">Bit 1</td>
///			<td border="1">Bit 0</td>
///		</tr>
///		<tr>
///			<td border="1">Channels 1-4 Byte</td>
///			<td border="1" colspan="2">Ch 1 Range</td>
///			<td border="1" colspan="2">Ch 2 Range</td>
///			<td border="1" colspan="2">Ch 3 Range</td>
///			<td border="1" colspan="2">Ch 4 Range</td>
///		</tr>
///		<tr>
///			<td border="1">Channels 5-8 Byte</td>
///			<td border="1" colspan="2">Ch 5 Range</td>
///			<td border="1" colspan="2">Ch 6 Range</td>
///			<td border="1" colspan="2">Ch 7 Range</td>
///			<td border="1" colspan="2">Ch 8 Range</td>
///		</tr>
///		<tr>
///			<td border="1">Channels 9-12 Byte</td>
///			<td border="1" colspan="2">Ch 9 Range</td>
///			<td border="1" colspan="2">Ch 10 Range</td>
///			<td border="1" colspan="2">Ch 11 Range</td>
///			<td border="1" colspan="2">Ch 12 Range</td>
///		</tr>
///		<tr>
///			<td border="1">Channels 13-16 Byte</td>
///			<td border="1" colspan="2">Ch 13 Range</td>
///			<td border="1" colspan="2">Ch 14 Range</td>
///			<td border="1" colspan="2">Ch 15 Range</td>
///			<td border="1" colspan="2">Ch 16 Range</td>
///		</tr>
///		</table>
///		>]
///		}
///
///	}
/// \enddot	
///
///
/// \subsection	mb_65	(0x65)  Get A/D & D/A Configuration
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Get A/D, D/A Configuration' Modbus PDU (0x65) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function}|{0x65}" ]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Device Config|Channels 1-4|Channels 5-8|Channels 9-12|Channels 13-16}|{0x65|?|?|?|?|?}"	]
///		}
///	}
/// \enddot
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=plaintext, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="Parameter 'config' Layout of IO Direction"]
///
///		subgraph cluster_3
///		{
///		label="Device Config Bit Packing"
///		d [ label=<
///		<table border="0" cellspacing="0" cellpadding="5">
///		<tr>
///			<td border="0"></td>
///			<td border="1">Bit 7</td>
///			<td border="1">Bit 6</td>
///			<td border="1">Bit 5</td>
///			<td border="1">Bit 4</td>
///			<td border="1">Bit 3</td>
///			<td border="1">Bit 2</td>
///			<td border="1">Bit 1</td>
///			<td border="1">Bit 0</td>
///		</tr>
///		<tr>
///			<td border="1">Device Config Byte</td>
///			<td border="1" colspan="4">A/D Voltage Reference</td>
///			<td border="1" colspan="4">A/D Channel Mode</td>
///		</tr>
///		</table>
///		>]
///		}
///
///		subgraph cluster_4
///		{
///		label="Channels Config Bit Packing"
///		c [ label=<
///		<table border="0" cellspacing="0" cellpadding="5">
///		<tr>
///			<td border="0"></td>
///			<td border="1">Bit 7</td>
///			<td border="1">Bit 6</td>
///			<td border="1">Bit 5</td>
///			<td border="1">Bit 4</td>
///			<td border="1">Bit 3</td>
///			<td border="1">Bit 2</td>
///			<td border="1">Bit 1</td>
///			<td border="1">Bit 0</td>
///		</tr>
///		<tr>
///			<td border="1">Channels 1-4 Byte</td>
///			<td border="1" colspan="2">Ch 1 Range</td>
///			<td border="1" colspan="2">Ch 2 Range</td>
///			<td border="1" colspan="2">Ch 3 Range</td>
///			<td border="1" colspan="2">Ch 4 Range</td>
///		</tr>
///		<tr>
///			<td border="1">Channels 5-8 Byte</td>
///			<td border="1" colspan="2">Ch 5 Range</td>
///			<td border="1" colspan="2">Ch 6 Range</td>
///			<td border="1" colspan="2">Ch 7 Range</td>
///			<td border="1" colspan="2">Ch 8 Range</td>
///		</tr>
///		<tr>
///			<td border="1">Channels 9-12 Byte</td>
///			<td border="1" colspan="2">Ch 9 Range</td>
///			<td border="1" colspan="2">Ch 10 Range</td>
///			<td border="1" colspan="2">Ch 11 Range</td>
///			<td border="1" colspan="2">Ch 12 Range</td>
///		</tr>
///		<tr>
///			<td border="1">Channels 13-16 Byte</td>
///			<td border="1" colspan="2">Ch 13 Range</td>
///			<td border="1" colspan="2">Ch 14 Range</td>
///			<td border="1" colspan="2">Ch 15 Range</td>
///			<td border="1" colspan="2">Ch 16 Range</td>
///		</tr>
///		</table>
///		>]
///		}
///
///	}
/// \enddot	
///
///
///
///
/// \subsection	mb_66	(0x66)  Get Extended Module Configuration
///
///
/// \dot
///	digraph diagram 
///	{
///     node  [ shape=record, fontname=Verdana, fontsize=8, style=solid, color="#999999" ]
///
///		graph [	label="'Get Extended Module Configuration' Modbus PDU (0x66) "]
///
///		subgraph cluster_1
///		{
///			label="Modbus Request"
///			request	[ label="{Function}|{0x66}"	]
///		}
///
///		subgraph cluster_2
///		{ 
///			label="Modbus Response"
///			response [ label="{Function|Model||Firmware Ver|Reserved Bytes}|{0x66|? (High)|? (Low)|1 Byte|13 Bytes}"	]
///		}
///	}
/// \enddot	
///
