/*
 * ceth.c
 * SeaMAX for Linux CEthernet Sample
 *
 * This code implements a simple demonstration of the SeaMAX Ethernet
 * discovery and configuration library.
 *
 * Sealevel and SeaMAX are registered trademarks of Sealevel Systems
 * Incorporated.
 *
 *  2008-2017 Sealevel Systems, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
#include <stdio.h>
#include <errno.h>
#include <cethernet.h>

#define MAXIMUM_DEVICES (25)



void print_info(ceth_device_p);

int main(int argc, char* argv[])
{


        ceth_device_p   arrayOfFoundDevices;
        ceth_device_p   devicePointer;
        int             deviceCount;


        // Allocate a buffer to hold the devices to be found
        arrayOfFoundDevices = CEthernet_Alloc(MAXIMUM_DEVICES);
        

        // Search the network by sending a UDP broadcast to find all
        // Sealevel type ethernet devices
        deviceCount = CEthernet_find_devices(Sealevel_All_Devices, 
                                        MAXIMUM_DEVICES, arrayOfFoundDevices);


        // If we have found at least one device, print
        if(deviceCount > 0)
        {
		int i;
                printf("Found %d Sealevel Devices\n\n", deviceCount);


                // Set a temporary pointer to the first device in the list
                devicePointer = arrayOfFoundDevices;


                for(i = 0; i < deviceCount; i++)
                {
                        // Print the device's information and increment the 
                        // pointer to the next device
                        print_info(devicePointer);
                        devicePointer = devicePointer->next;
			// NOTE:  devicePointer++ will NOT work here.
			// The memory Alloc'd is no longer a contiguous block.
                }
        }
	else if (deviceCount == -EPERM)
	{
		printf("Insufficent privileges.  Try running as root or superuser.\n\n");
	}


    /*
    // The following code is for modifying the device's settings

    // used for new ip_address, subnet_mask, gateway
        ceth_ip_addr ipAddress, netmask, gateway;  

        ipAddress.c[0] = 192;
        ipAddress.c[1] = 168;
        ipAddress.c[2] = 42;
        ipAddress.c[3] = 91;
        
        netmask.c[0] = 255;
        netmask.c[1] = 255;
        netmask.c[2] = 255;
        netmask.c[3] = 0;

        gateway.c[0] = 192;
        gateway.c[1] = 168;
        gateway.c[2] = 42;
        gateway.c[3] = 11;

    // To set a single device's IPAddress (and disable DHCP):
	int result = CEthernet_set_information(arrayOfFoundDevices, SetIPAddress, ipAddress, netmask, gateway);
    
          
    // example of setting two masks at once:
        result = CEthernet_set_information(arrayOfFoundDevices,(enum ceth_set_types)(SetDHCP | SetName), "NewDevName");


    // NOTE: When setting DHCP, it may take a little time for the DHCP server to assign a new IP address,
    //       so you'd better wait a little bit before querying the device again

    // Also, you cannot OR SetIPAddress and SetDHCP.
    */

	return 0;
}




// Prints a device's configuration
void print_info(ceth_device_p devPointer)
{
        // These are pointers to the first element of each array.
        unsigned char *IP = devPointer->ip_address.c;
        unsigned char *NM = devPointer->net_mask.c;
        unsigned char *GW = devPointer->gateway.c;
        unsigned char *MAC = devPointer->mac_address.c;

        printf("DEVICE (%s)\n", devPointer->name);
        printf("------------------------------------------------\n");

        // There are two basic types of Sealevel devices, SeaIO and SeaLINK
        switch (devPointer->type)
        {
                case SeaIO_Ethernet: 
                        printf("  Device Type: SeaIO Ethernet Module\n");
                        break;
                case SeaLink_Dev:    
                        printf("  Device Type: SeaLINK Ethernet Server\n");
                        break;
                default: 
                        printf("  Device Type: Unknown Device Type\n");
                        break;
        }

        printf("  MAC Address: %2.2X:%2.2X:%2.2X:%2.2X:%2.2X:%2.2X\n", 
                               MAC[0], MAC[1], MAC[2], MAC[3], MAC[4], MAC[5] );

        printf("  DHCP Enabled: %s\n", devPointer->dhcp_enabled ? "Yes" : "No");

        printf("  IP:           %d.%d.%d.%d\n", IP[0], IP[1], IP[2], IP[3] );

        printf("  NetMask:      %d.%d.%d.%d\n", NM[0], NM[1], NM[2], NM[3] );
        
        if(devPointer->gateway.i == 0)
        {
           printf("  Gateway:      No Gateway Defined\n");
        }
        else
        {
           printf("  Gateway:      %d.%d.%d.%d\n", GW[0], GW[1], GW[2], GW[3] );
        }
        
        printf("------------------------------------------------\n");
        printf("\n");
        
}
