/*
 * TestIt.h
 * SeaMAX for Linux Sealevel Systems Diagnostic
 *
 * This code defines the commands available to the linssd utility.
 *
 * Sealevel and SeaMAX are registered trademarks of Sealevel Systems
 * Incorporated.
 *
 *  2008-2017 Sealevel Systems, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
#ifndef __TESTIT_H__
#define __TESTIT_H__

#define MAXLENGTH 300
#define LINELENGTH 78

// A structure defining a Command.
typedef struct {
	char cmd;                    //The command 'O' == doOpen()
	char Description[MAXLENGTH]; //Description of what this command does
	char Arg1[MAXLENGTH];        //Argument 1 request explaination string
	char Arg2[MAXLENGTH];        //Argument 2 request explaination string
	int ArgCount;                //Number of arguments this command requries
	void (*func)(char*, char*);  //The function this command calls - doOpen()
} Command;

// Internal test app routines.
void ShowMenu(void);
void ShowLine(char *instr);
Command *findCommand(const char *buff);
int getOneArg(const char * buff, char *result);
int getTwoArgs(const char * buff, char *result1, char *result2);
void printError(int error, const char *buff);
void devInfo();
void findEth();
void printBaud(baud_rates_t baud);
void printParity(parity_t parity);
void printType(unsigned char type);

// The commands the test app has access to.
void doOpenMod(char*, char*);
void doSetMod(char *, char *);
void doCloseMod(char*, char*);
void doOpenDev(char *, char *);
void doSetDev(char *, char *);
void doSetDevID(char *, char *);
void doGetInfo(char*, char*);
void doSetup(char *, char *);
void doReadAll(char*, char*);
void doWriteBank(char *, char *);
void doSetRange(char *, char *);
void doMonitorAtoD(char *, char *);
void doWriteDtoA(char *, char *);
void doScan(char*, char*);
void doQuit(char*, char*);

static Command cmds[] = {
	{ 'O',	
		"[O]pen SeaIO Module", 
		" Module name (example: sealevel_rtu://dev/ttyUSB0)", 
		"", 
		1, 
		doOpenMod
	},
	{ 'S',	
		"[S]et Module Connection Parameters (not Ethernet)", 
		" Desired Baud Rate (baud_rates_t 1=1200, 2=2400, etc)", 
		" Desired Parity (parity_t 0=None, 1=Odd, 2=Even)", 
		2, 
		doSetMod
	},
	{ 'C',	
		"[C]lose SeaIO Module", 
		"", 
		"", 
		0, 
		doCloseMod
	},
	{ 'P',	
		"O[p]en SeaIO Device", 
		" SlaveID of the device you wish to access [1, 247]", 
		"", 
		1, 
		doOpenDev
	},
	{ 'E',	
		"S[e]t SeaIO Device Communication Parameters (not Ethernet)", 
		" Desired Baud Rate (baud_rates_t 1=1200, 2=2400, etc)", 
		" Desired Parity (parity_t 0=None, 1=Odd, 2=Even)", 
		2, 
		doSetDev
	},
	{ 'T',	
		"Se[t] SeaIO Device SlaveID", 
		" New slaveID number [1, 247]", 
		"", 
		1, 
		doSetDevID
	},
	{ 'I',	
		"Get [I]nformation", 
		"", 
		"", 
		0, 
		doGetInfo
	},
	{ 'U',  
		"Set[u]p adapter", 
		" Setup control word 1 (decimal)", 
		" Setup control word 2 (decimal)", 
		2, 
		doSetup
	},
	{ 'H',  
		"Set A/D c[h]annel range", 
		" Channel to set range", 
		" Range (0=0-5, 1=-5-5, 2=0-10, 3=-10-10)", 
		2, 
		doSetRange
	},
	{ 'R',	
		"[R]ead All IO", 
		"", 
		"", 
		0, 
		doReadAll
	},
	{ 'W',	
		"[W]rite a byte to a bank", 
		" The bank number to write to (1 indexed)", 
		" The data byte to write to the bank (in decimal)", 
		2, 
		doWriteBank
	},
	{ 'K',	
		"[K]night Rider", 
		" Number of repetitions", 
		"", 
		1, 
		doScan
	},
	{ 'A',	
		"monitor [A]nalog channels", 
		"", 
		"", 
		0, 
		doMonitorAtoD
	},
	{ 'D',	
		"write [D]igital to analog converter", 
		"DAC channel to write to", 
		"Value to write (decimal)", 
		2, 
		doWriteDtoA
	},
	{ 'Q',	
		"[Q]uit", 
		"", 
		"", 
		0,	
		doQuit
	},
};

#endif //__TESTIT_H__
